@@ -8,13 +8,14 @@ import astropy.units as u
 from astropy.visualization.wcsaxes import WCSAxes
 import sunpy.visualization.wcsaxes_compat as wcsaxes_compat
 try:
-    from sunpy.visualization.animator import ImageAnimator, ImageAnimatorWCS, LineAnimator
+    from sunpy.visualization.animator import ImageAnimator, LineAnimator
 except ImportError:
-    from sunpy.visualization.imageanimator import ImageAnimator, ImageAnimatorWCS, LineAnimator
+    from sunpy.visualization.imageanimator import ImageAnimator, LineAnimator
 
 from ndcube import utils
 from ndcube.utils.cube import _get_extra_coord_edges
 from ndcube.mixins import sequence_plotting
+from ndcube.visualization.animator import ImageAnimatorWCS
 
 __all__ = ['NDCubePlotMixin']
 
@@ -426,14 +427,23 @@ class NDCubePlotMixin:
                                 "valid unit string in order to set data_unit.")
             else:
                 data = (self.data * self.unit).to(data_unit).value
+        # If min or max of data is inf or nan, set ylim of plot manually.
+        ylim = kwargs.pop("ylim", None)
+        if ylim is None and not np.isfinite([data.min(), data.max()]).all():
+            if self.mask is not None:
+                good_data = data[np.invert(self.mask)]
+            else:
+                good_data = data
+            ylim = (np.nanmin(good_data), np.nanmax(good_data))
+
         # Combine data with mask
         # data = np.ma.masked_array(data, self.mask)
         # Set default y label
         default_ylabel = f"Data [{unit_x_axis}]"
         # Initiate line animator object.
         ax = LineAnimator(data, plot_axis_index=plot_axis_index, axis_ranges=axes_coordinates,
-                          xlabel=default_xlabel,
-                          ylabel=f"Data [{data_unit}]", **kwargs)
+                          xlabel=default_xlabel, ylabel=f"Data [{data_unit}]", ylim=ylim,
+                          **kwargs)
         return ax
 
     def _derive_axes_coordinates(self, axes_coordinates, axes_units, data_shape, edges=False):
@@ -452,10 +462,10 @@ class NDCubePlotMixin:
                 axis_label_text = self.world_axis_physical_types[i]
                 # If the shape of the data is not 1, or all the axes are not dependent
                 if new_axis_coordinate.ndim != 1 and new_axis_coordinate.ndim != len(data_shape):
-                    index = utils.wcs.get_dependent_data_axes(self.wcs, i, self.missing_axes)
-                    reduce_axis = np.where(index == np.array([i]))[0]
-
-                    index = np.delete(index, reduce_axis)
+                    dependent_axes = utils.wcs.get_dependent_data_axes(self.wcs, i,
+                                                                       self.missing_axes)
+                    reduce_axis = np.where(dependent_axes == np.array([i]))[0]
+                    index = np.delete(np.arange(len(dependent_axes)), reduce_axis)
                     # Reduce the data by taking mean
                     new_axis_coordinate = np.mean(new_axis_coordinate, axis=tuple(index))
 
