@@ -884,22 +884,22 @@ def test_ndcubeordered(test_input, expected):
 
 
 @pytest.mark.parametrize("test_input,expected", [
-    ((cubem, [2]), u.Quantity([1.02e-09, 1.04e-09, 1.06e-09, 1.08e-09], unit=u.m)),
-    ((cubem, ['em']), u.Quantity([1.02e-09, 1.04e-09, 1.06e-09, 1.08e-09], unit=u.m))
+    ((cubem, [2]), (u.Quantity([1.02e-09, 1.04e-09, 1.06e-09, 1.08e-09], unit=u.m),)),
+    ((cubem, ['em']), (u.Quantity([1.02e-09, 1.04e-09, 1.06e-09, 1.08e-09], unit=u.m),))
 ])
 def test_all_world_coords_with_input(test_input, expected):
-    all_coords = test_input[0].axis_world_coords(*test_input[1])
+    all_coords = test_input[0].axis_world_coords_values(*test_input[1])
     for i in range(len(all_coords)):
         np.testing.assert_allclose(all_coords[i].value, expected[i].value)
         assert all_coords[i].unit == expected[i].unit
 
 
 @pytest.mark.parametrize("test_input,expected", [
-    ((cubem, [2]), u.Quantity([1.01e-09, 1.03e-09, 1.05e-09, 1.07e-09, 1.09e-09], unit=u.m)),
-    ((cubem, ['em']), u.Quantity([1.01e-09, 1.03e-09, 1.05e-09, 1.07e-09, 1.09e-09], unit=u.m))
+    ((cubem, [2]), (u.Quantity([1.01e-09, 1.03e-09, 1.05e-09, 1.07e-09, 1.09e-09], unit=u.m),)),
+    ((cubem, ['em']), (u.Quantity([1.01e-09, 1.03e-09, 1.05e-09, 1.07e-09, 1.09e-09], unit=u.m),))
 ])
-def test_all_world_coords_with_input_and_kwargs(test_input, expected):
-    all_coords = test_input[0].axis_world_coords(*test_input[1], **{"edges": True})
+def test_all_world_coord_values_with_input_and_kwargs(test_input, expected):
+    all_coords = test_input[0].axis_world_coords_values(*test_input[1], **{"edges": True})
     for i in range(len(all_coords)):
         np.testing.assert_allclose(all_coords[i].value, expected[i].value)
         assert all_coords[i].unit == expected[i].unit
@@ -915,10 +915,11 @@ def test_all_world_coords_with_input_and_kwargs(test_input, expected):
                                     [1., 1., 1.]], unit=u.deg),
                         u.Quantity([[1.26915033e-05, 4.99987815e-01, 9.99962939e-01],
                                     [1.26918126e-05, 5.00000000e-01, 9.99987308e-01]],
-                                   unit=u.deg)))
+                                   unit=u.deg),
+                        u.Quantity([1.02e-09], unit=u.m)))
 ])
-def test_axis_world_coords_without_input(test_input, expected):
-    all_coords = test_input.axis_world_coords()
+def test_axis_world_coords_values_without_input(test_input, expected):
+    all_coords = test_input.axis_world_coords_values()
     for i in range(len(all_coords)):
         np.testing.assert_allclose(all_coords[i].value, expected[i].value)
         assert all_coords[i].unit == expected[i].unit
@@ -940,3 +941,13 @@ def test_explode_along_axis(test_input, expected):
     assert isinstance(output[inp_slice], exp_type_cube)
     assert isinstance(output.meta, exp_meta_seq)
     assert isinstance(output[inp_slice].meta, exp_meta_cube)
+
+
+def test_array_axis_physical_types():
+    expected = [
+            ('custom:pos.helioprojective.lon', 'custom:pos.helioprojective.lat'),
+            ('custom:pos.helioprojective.lon', 'custom:pos.helioprojective.lat'),
+            ('em.wl',), ('time',)]
+    output = cube_disordered.array_axis_physical_types
+    for i, expected_i in enumerate(expected):
+        assert all([physical_type in expected_i for physical_type in output[i]])
